import pytest


@pytest.fixture(name="sequence1")
def fixture_sequence_1():
    return 'NLYIQWLKDGGPSSGRPPPS'


@pytest.fixture(name="sequence2")
def fixture_sequence_2():
    return 'MALPVTALLLPLALLLHAARPSQFRVSPLDRTWNLGETVELKCQVLLSNPTSGCSWLFQPRGA'\
           'AASPTFLLYLSQNKPKAAEGLDTQRFSGKRLGDTFVLTLSDFRRENEGCYFCSALSNSIMYFS'\
           'HFVPVFLPAKPTTTPAPRPPTPAPTIASQPLSLRPEACRPAAGGAVHTRGLDFACDIYIWAPL'\
           'AGTCGVLLLSLVITLYCNHRNRRRVCKCPRPVVKSGDKPSLSARYV'


@pytest.fixture(name="sequence3")
def fixture_sequence_3():
    return 'ggctgacggctgggttaagaagtttactgaggcagttaacgcctttaagggtttggactggatc'\
           'cgctgccaagttgtccaagttccttgattggatcaaatccaagatcatcccggagctcagagag'\
           'agagcggagtttgttaagaatcttaggcagcttcctcttctcgaggcccagatcaccactttgg'\
           'agcactccaaccctaatcaggagacccaagaacagcttttctcgaacgtccaatacctggcaca'\
           'ccactgtaggaagaacgctccgctctatgcagcggaagcccggagagttttcgcactagagaaa'\
           'cgcgtccttggagcaatgcagttcaagaccaagaatcgaattgaacctgtttgctgtttgatcc'\
           'atggaacgccgggcactggtaaatcacttgccacgactattattggcaggaagatcgctgagta'\
           'cgagaatagcggggtctatagtttgccacctgacccagaccactttgatggctacgccgagcag'\
           'gcagttgtaattatggatgatctgcatcagaacccagacggcaaagatatgagcttgttttgtc'\
           'agatggtttccaccacccccttcgtggttccgatggctgctctcgaggataaaggtagactttt'\
           'cacctccaaatatgtgctggcctcaacaaatgccaaccatatccatccagttacagtcgccgat'\
           'ggaaaggcccttcagcgccgcttccacttcgacacggacattgaattgatggatggcttcgtga'\
           'aaaacgggaaactagatattcagagggcaaccgaggcatgtgaagactgttctccgatcaactt'\
           'tcagaagtgcatgcctctcatttgtggtaaggctctccagctccgtagcaagaagggtgatggc'\
           'atgagatacagcattgataccatgatcacagagatgcgcagggagtcagcccgacgctataata'\
           'ttgggaatgttatagaggcactcttccaa'
